==> apigeelint-0.4.1.tgz: package/lib/package/plugins/useTargetServers.js <==
/*
  Copyright 2019 Google LLC

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

      https://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
*/

//useTargetServers
//| &nbsp; |:white_medium_square:| TD002 | Use Target Server |  Discourage use of direct URLs in Target Server. |

var plugin = {
    ruleId: "TD002",
    name: "Discourage use of direct URLs in Target Server.",
    message: "Using a Target Server simplifies CI/CD.",
    fatal: false,
    severity: 1, //warn
    nodeType: "TargetEndpoint",
    enabled: true
  },
  debug = require("debug")("bundlelinter:" + plugin.name),
  xpath = require("xpath");

var onTargetEndpoint = function(target, cb) {
  //get /TargetEndpoint/HTTPTargetConnection/URL
  var hadWarnErr = false;
  var url = xpath.select(
      "/TargetEndpoint/HTTPTargetConnection/URL/text()",
      target.getElement()
    );
  
  if (url) {
    var attr = xpath.select("/TargetEndpoint/@name", target.getElement() );
    target.addMessage({
      plugin,
      message: "TargetEndpoint (" + attr[0].value + ") is using URL, using a Target Server simplifies CI/CD."
    });
    hadWarnErr=true;
  }

  if (typeof cb == "function") {
    cb(null,hadWarnErr);
  }
  return hadWarnErr;
};

module.exports = {
  plugin,
  onTargetEndpoint
};

==> apigeelint-0.4.9.tgz: package/lib/package/plugins/useTargetServers.js <==
/*
  Copyright 2019 Google LLC

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

      https://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
*/

//useTargetServers
//| &nbsp; |:white_medium_square:| TD002 | Use Target Server |  Discourage use of direct URLs in Target Server. |

var plugin = {
    ruleId: "TD002",
    name: "Discourage use of direct URLs in Target Server.",
    message: "Using a Target Server simplifies CI/CD.",
    fatal: false,
    severity: 1, //warn
    nodeType: "TargetEndpoint",
    enabled: true
  },
  debug = require("debug")("bundlelinter:" + plugin.name),
  xpath = require("xpath");

var onTargetEndpoint = function(target, cb) {
  //get /TargetEndpoint/HTTPTargetConnection/URL
  var hadWarnErr = false;
  var url = xpath.select(
      "/TargetEndpoint/HTTPTargetConnection/URL/text()",
      target.getElement()
    );
  
  if (url && url[0] !== undefined ) {
    var attr = xpath.select("/TargetEndpoint/@name", target.getElement() );
    target.addMessage({
      plugin,
      message: "TargetEndpoint (" + attr[0].value + ") is using URL (" + url + "), using a Target Server simplifies CI/CD."
    });
    hadWarnErr=true;
  }

  if (typeof cb == "function") {
    cb(null,hadWarnErr);
  }
  return hadWarnErr;
};

module.exports = {
  plugin,
  onTargetEndpoint
};
